@@ -16,8 +16,7 @@ import aiohttp
 import aiohttp.web
 from aiohttp_rpc import JsonRpcMethod
 from aiohttp_rpc import middlewares as rpc_middlewares
-from aiohttp_rpc.errors import InvalidParams as InvalidParamsError
-from aiohttp_rpc.errors import ServerError
+from aiohttp_rpc.errors import InvalidParams, ServerError
 from aiohttp_rpc.server import WsJsonRpcServer
 import click
 from loguru import logger
@@ -30,9 +29,17 @@ from yarl import URL
 from instawow import __version__, db, matchers, models
 from instawow import results as R
 from instawow.cataloguer import CatalogueEntry
-from instawow.common import Flavour, Strategy
+from instawow.common import ChangelogFormat, Flavour, Strategy
 from instawow.config import Config, GlobalConfig
-from instawow.manager import LocksType, Manager, TraceRequestCtx, init_web_client, is_outdated
+from instawow.github_auth import DeviceCodeResponse, get_codes, poll_for_access_token
+from instawow.manager import (
+    LocksType,
+    Manager,
+    TraceRequestCtx,
+    contextualise,
+    init_web_client,
+    is_outdated,
+)
 from instawow.resolvers import Defn
 from instawow.utils import evolve_model_obj
 from instawow.utils import run_in_thread as t
@@ -42,7 +49,10 @@ from . import frontend
 
 _T = TypeVar('_T')
 _P = ParamSpec('_P')
-ManagerBoundCoroFn: TypeAlias = 'Callable[Concatenate[Manager, _P], Awaitable[_T]]'
+_ManagerBoundCoroFn: TypeAlias = 'Callable[Concatenate[Manager, _P], Awaitable[_T]]'
+_ManagerQueue: TypeAlias = (
+    'asyncio.Queue[tuple[asyncio.Future[object], str, _ManagerBoundCoroFn[..., object]]]'
+)
 
 
 LOCALHOST = '127.0.0.1'
@@ -55,7 +65,7 @@ class _ConfigError(ServerError):
 
 @contextmanager
 def _reraise_validation_error(
-    error_class: type[ServerError | InvalidParamsError] = ServerError,
+    error_class: type[ServerError | InvalidParams] = ServerError,
     values: dict[Any, Any] | None = None,
 ) -> Iterator[None]:
     try:
@@ -89,7 +99,7 @@ class BaseParams(BaseModel):
         cls, method: str, managers: _ManagerWorkQueue, app_window: toga.MainWindow | None
     ) -> JsonRpcMethod:
         async def respond(**kwargs: Any) -> BaseModel:
-            with _reraise_validation_error(InvalidParamsError, kwargs):
+            with _reraise_validation_error(InvalidParams, kwargs):
                 params = cls.parse_obj(kwargs)
             return await params.respond(managers, app_window)
 
@@ -109,8 +119,8 @@ class _DefnParamMixin(BaseModel):
     defns: typing.List[Defn]
 
 
-@_register_method('config/write')
-class WriteConfigParams(_ProfileParamMixin, BaseParams):
+@_register_method('config/write_profile')
+class WriteProfileConfigParams(_ProfileParamMixin, BaseParams):
     addon_dir: Path
     game_flavour: Flavour
     infer_game_flavour: bool
@@ -142,16 +152,16 @@ class WriteConfigParams(_ProfileParamMixin, BaseParams):
             return config
 
 
-@_register_method('config/read')
-class ReadConfigParams(_ProfileParamMixin, BaseParams):
+@_register_method('config/read_profile')
+class ReadProfileConfigParams(_ProfileParamMixin, BaseParams):
     async def respond(
         self, managers: _ManagerWorkQueue, app_window: toga.MainWindow | None
     ) -> Config:
         return await _read_config(self.profile)
 
 
-@_register_method('config/delete')
-class DeleteConfigParams(_ProfileParamMixin, BaseParams):
+@_register_method('config/delete_profile')
+class DeleteProfileConfigParams(_ProfileParamMixin, BaseParams):
     async def respond(
         self, managers: _ManagerWorkQueue, app_window: toga.MainWindow | None
     ) -> None:
@@ -162,7 +172,7 @@ class DeleteConfigParams(_ProfileParamMixin, BaseParams):
         await managers.run(self.profile, delete_profile)
 
 
-@_register_method('config/list')
+@_register_method('config/list_profiles')
 class ListProfilesParams(BaseParams):
     @t
     def respond(
@@ -171,30 +181,90 @@ class ListProfilesParams(BaseParams):
         return GlobalConfig().list_profiles()
 
 
+@_register_method('config/update_global')
+class UpdateGlobalConfigParams(BaseParams):
+    cfcore_access_token: typing.Optional[str]
+
+    async def respond(
+        self, managers: _ManagerWorkQueue, app_window: toga.MainWindow | None
+    ) -> GlobalConfig:
+        async with managers.locks['update global config']:
+            with _reraise_validation_error(_ConfigError):
+                existing_global_config = await t(GlobalConfig.read)()
+                new_global_config = evolve_model_obj(
+                    existing_global_config,
+                    access_tokens=evolve_model_obj(
+                        existing_global_config.access_tokens, cfcore=self.cfcore_access_token
+                    ),
+                )
+                await t(new_global_config.write)()
+
+        managers.unload_all()
+        return new_global_config
+
+
+@_register_method('config/read_global')
+class ReadGlobalConfigParams(BaseParams):
+    @t
+    def respond(
+        self, managers: _ManagerWorkQueue, app_window: toga.MainWindow | None
+    ) -> GlobalConfig:
+        return GlobalConfig.read()
+
+
+class GithubCodesResponse(TypedDict):
+    user_code: str
+    verification_uri: str
+
+
+@_register_method('config/initiate_github_auth_flow')
+class InitiateGithubAuthFlowParams(BaseParams):
+    async def respond(
+        self, managers: _ManagerWorkQueue, app_window: toga.MainWindow | None
+    ) -> GithubCodesResponse:
+        return await managers.initiate_github_auth_flow()
+
+
+class GithubAuthFlowStatusReport(TypedDict):
+    status: Literal['success', 'failure']
+
+
+@_register_method('config/query_github_auth_flow_status')
+class QueryGithubAuthFlowStatusParams(BaseParams):
+    async def respond(
+        self, managers: _ManagerWorkQueue, app_window: toga.MainWindow | None
+    ) -> GithubAuthFlowStatusReport:
+        return {'status': await managers.wait_for_github_auth_completion()}
+
+
+@_register_method('config/cancel_github_auth_flow')
+class CancelGithubAuthFlowParams(BaseParams):
+    async def respond(
+        self, managers: _ManagerWorkQueue, app_window: toga.MainWindow | None
+    ) -> None:
+        managers.cancel_github_auth_polling()
+
+
 class Source(TypedDict):
-    source: str
     name: str
     supported_strategies: list[Strategy]
-    supports_rollback: bool
-    changelog_format: str
+    changelog_format: ChangelogFormat
 
 
 @_register_method('sources/list')
 class ListSourcesParams(_ProfileParamMixin, BaseParams):
     async def respond(
         self, managers: _ManagerWorkQueue, app_window: toga.MainWindow | None
-    ) -> list[Source]:
+    ) -> dict[str, Source]:
         manager = await managers.get_manager(self.profile)
-        return [
-            {
-                'source': r.source,
+        return {
+            r.source: {
                 'name': r.name,
                 'supported_strategies': sorted(r.strategies, key=list(Strategy).index),
-                'supports_rollback': Strategy.version in r.strategies,
-                'changelog_format': r.changelog_format.value,
+                'changelog_format': r.changelog_format,
             }
             for r in manager.resolvers.values()
-        ]
+        }
 
 
 @_register_method('list')
@@ -380,11 +450,14 @@ class ReconcileParams(_ProfileParamMixin, BaseParams):
             if m
         ]
         return [
-            AddonMatch(folders=[{'name': f.name, 'version': f.version} for f in a], matches=m)
-            for a, m in matches
-        ] + [
-            AddonMatch(folders=[{'name': f.name, 'version': f.version}], matches=[])
-            for f in sorted(leftovers - frozenset(i for a, _ in matches for i in a))
+            *(
+                AddonMatch(folders=[{'name': f.name, 'version': f.version} for f in a], matches=m)
+                for a, m in matches
+            ),
+            *(
+                AddonMatch(folders=[{'name': f.name, 'version': f.version}], matches=[])
+                for f in sorted(leftovers - frozenset(i for a, _ in matches for i in a))
+            ),
         ]
 
 
@@ -513,9 +586,7 @@ class ConfirmDialogueParams(BaseParams):
         return {'ok': ok}
 
 
-def _init_json_rpc_web_client(
-    progress_reporters: set[tuple[Manager, models.Pkg, Callable[[], float]]],
-) -> aiohttp.ClientSession:
+def _init_json_rpc_web_client():
     async def do_on_request_end(
         client_session: aiohttp.ClientSession,
         trace_config_ctx: Any,
@@ -538,40 +609,53 @@ def _init_json_rpc_web_client(
             progress_reporters.add(entry)
             content.on_eof(lambda: progress_reporters.remove(entry))
 
+    progress_reporters: set[tuple[Manager, models.Pkg, Callable[[], float]]] = set()
+
     trace_config = aiohttp.TraceConfig()
     trace_config.on_request_end.append(do_on_request_end)
     trace_config.freeze()
-    return init_web_client(trace_configs=[trace_config])
+
+    return (init_web_client(trace_configs=[trace_config]), progress_reporters)
 
 
 class _ManagerWorkQueue:
     def __init__(self):
         self._loop = asyncio.get_running_loop()
 
-        self._queue: asyncio.Queue[
-            tuple[asyncio.Future[object], str, ManagerBoundCoroFn[..., object]]
-        ] = asyncio.Queue()
-        self._managers: dict[str, tuple[Manager, Callable[[], None]]] = {}
-        self._progress_reporters: set[tuple[Manager, models.Pkg, Callable[[], float]]] = set()
+        self._queue: _ManagerQueue = asyncio.Queue()
 
-        self._web_client = _init_json_rpc_web_client(self._progress_reporters)
         self.locks: LocksType = defaultdict(asyncio.Lock)
 
-    async def cleanup(self):
-        for _, close_db_conn in self._managers.values():
-            close_db_conn()
+        self._managers: dict[str, tuple[Manager, Callable[[], None]]] = {}
+
+        self._web_client, self._download_progress_reporters = _init_json_rpc_web_client()
+
+        self._github_auth_device_codes = None
+        self._github_auth_flow_task = None
+
+    async def __aenter__(self):
+        self._listener = self._loop.create_task(self._listen())
+
+    async def __aexit__(self, *args: object):
+        self._listener.cancel()
+        self.unload_all()
         await self._web_client.close()
 
     def unload(self, profile: str):
         if profile in self._managers:
+            logger.debug(f'unloading {profile}')
             _, close_db_conn = self._managers.pop(profile)
             close_db_conn()
 
+    def unload_all(self):
+        for profile in self._managers:
+            self.unload(profile)
+
     async def _schedule_item(
         self,
         future: asyncio.Future[object],
         profile: str,
-        coro_fn: ManagerBoundCoroFn[_P, object],
+        coro_fn: _ManagerBoundCoroFn[_P, object],
     ):
         try:
             async with self.locks['modify profile', profile]:
@@ -588,17 +672,17 @@ class _ManagerWorkQueue:
         else:
             future.set_result(result)
 
-    async def listen(self):
-        Manager.contextualise(web_client=self._web_client, locks=self.locks)
+    async def _listen(self):
+        contextualise(web_client=self._web_client, locks=self.locks)
         while True:
             item = await self._queue.get()
             asyncio.create_task(self._schedule_item(*item))
             self._queue.task_done()
 
-    async def run(self, profile: str, coro_fn: ManagerBoundCoroFn[..., _T]) -> _T:
+    async def run(self, profile: str, coro_fn: _ManagerBoundCoroFn[..., _T]) -> _T:
         future = self._loop.create_future()
         self._queue.put_nowait((future, profile, coro_fn))
-        return await asyncio.wait_for(future, None)
+        return await future
 
     async def get_manager(self, profile: str):
         async def get_manager(manager: Manager):
@@ -608,17 +692,54 @@ class _ManagerWorkQueue:
 
     async def get_manager_download_progress(self, profile: str):
         manager = await self.get_manager(profile)
-        return ((p, r()) for m, p, r in self._progress_reporters if m is manager)
+        return ((p, r()) for m, p, r in self._download_progress_reporters if m is manager)
+
+    async def initiate_github_auth_flow(self):
+        async def _finalise_github_auth_flow():
+            result = await poll_for_access_token(
+                self._web_client, codes['device_code'], codes['interval']
+            )
+
+            async with self.locks['update global config']:
+                existing_global_config = await t(GlobalConfig.read)()
+                new_global_config = evolve_model_obj(
+                    existing_global_config,
+                    access_tokens=evolve_model_obj(
+                        existing_global_config.access_tokens, github=result
+                    ),
+                )
+                await t(new_global_config.write)()
+
+            self.unload_all()
+
+        if self._github_auth_device_codes is None:
+            self._github_auth_device_codes = codes = await get_codes(self._web_client)
+            self._github_auth_flow_task = self._loop.create_task(_finalise_github_auth_flow())
+        return self._github_auth_device_codes
+
+    async def wait_for_github_auth_completion(self):
+        if self._github_auth_flow_task is not None:
+            try:
+                await self._github_auth_flow_task
+            except BaseException:
+                return 'failure'
+            self._github_auth_flow_task = None
+        self._github_auth_device_codes = None
+        return 'success'
+
+    def cancel_github_auth_polling(self):
+        if self._github_auth_flow_task is not None:
+            self._github_auth_flow_task.cancel()
+            self._github_auth_flow_task = None
+        self._github_auth_device_codes = None
 
 
 async def create_app(app_window: toga.MainWindow | None = None):
     managers = _ManagerWorkQueue()
 
-    async def start_managers(app: aiohttp.web.Application):
-        managers_listen = asyncio.create_task(managers.listen())
-        yield
-        managers_listen.cancel()
-        await managers.cleanup()
+    async def listen(app: aiohttp.web.Application):
+        async with managers:
+            yield
 
     async def get_index(request: aiohttp.web.Request):
         return aiohttp.web.Response(
@@ -682,7 +803,7 @@ async def create_app(app_window: toga.MainWindow | None = None):
             aiohttp.web.get('/api', rpc_server.handle_http_request),
         ]
     )
-    app.cleanup_ctx.append(start_managers)
+    app.cleanup_ctx.append(listen)
     app.freeze()
     return app
 
