@@ -158,7 +158,7 @@ def run_with_progress(awaitable: Awaitable[_T]) -> _T:
     async def run():
         with make_progress_bar() as progress_bar, _cancel_tickers(progress_bar) as tickers:
             async with _init_cli_web_client(progress_bar, tickers) as web_client:
-                _manager.Manager.contextualise(web_client=web_client)
+                _manager.contextualise(web_client=web_client)
                 return await awaitable
 
     return asyncio.run(run())
@@ -188,9 +188,7 @@ class ManagerWrapper:
         except FileNotFoundError:
             config = self.ctx.invoke(configure)
 
-        setup_logging(
-            config.logging_dir, self.ctx.params['log_level'], self.ctx.params['log_to_stderr']
-        )
+        setup_logging(config.logging_dir, self.ctx.params['log_level'])
         manager, close_db_conn = _manager.Manager.from_config(config)
         self.ctx.call_on_close(close_db_conn)
 
@@ -254,13 +252,6 @@ def _set_log_level(_: click.Context, __: click.Parameter, value: bool):
     callback=_set_log_level,
     help='Log more things.',
 )
-@click.option(
-    '--log-to-stderr',
-    is_flag=True,
-    default=False,
-    help='Log to stderr for development.',
-    hidden=True,
-)
 @click.option(
     '--profile',
     '-p',
@@ -268,7 +259,7 @@ def _set_log_level(_: click.Context, __: click.Parameter, value: bool):
     help='Activate the specified profile.',
 )
 @click.pass_context
-def cli(ctx: click.Context, log_level: str, log_to_stderr: bool, profile: str) -> None:
+def cli(ctx: click.Context, log_level: str, profile: str) -> None:
     "Add-on manager for World of Warcraft."
     _apply_patches()
     ctx.obj = ManagerWrapper(ctx)
@@ -1002,7 +993,7 @@ def configure(
     if _EditableConfigOptions.github_access_token in config_options and ask(
         confirm('Set up GitHub authentication?')
     ):
-        github_access_token = run_with_progress(_github_oauth_flow())
+        github_access_token = asyncio.run(_github_oauth_flow())
         global_config_values['access_tokens']['github'] = github_access_token
 
     global_config = GlobalConfig(**global_config_values).write()
@@ -1080,6 +1071,6 @@ def gui(ctx: click.Context) -> None:
         global_config=global_config, profile='__jsonrpc__'
     ).ensure_dirs()
     params = ctx.find_root().params
-    setup_logging(dummy_jsonrpc_config.logging_dir, params['log_level'], params['log_to_stderr'])
+    setup_logging(dummy_jsonrpc_config.logging_dir, params['log_level'])
 
     InstawowApp(version=__version__).main_loop()
