@@ -3,11 +3,26 @@ from __future__ import annotations
 import asyncio
 
 import aiohttp
+from typing_extensions import TypedDict
 
 CLIENT_ID = 'aa178904bdf5143e93ec'
 
 
-async def get_codes(web_client: aiohttp.ClientSession):
+class DeviceCodeResponse(TypedDict):
+    device_code: str
+    user_code: str
+    verification_uri: str
+    expires_in: int
+    interval: int
+
+
+class AccessTokenResponse(TypedDict):
+    access_token: str
+    token_type: str
+    scope: str
+
+
+async def get_codes(web_client: aiohttp.ClientSession) -> DeviceCodeResponse:
     async with web_client.post(
         'https://github.com/login/device/code',
         headers={'Accept': 'application/json'},
@@ -19,7 +34,7 @@ async def get_codes(web_client: aiohttp.ClientSession):
 
 async def poll_for_access_token(
     web_client: aiohttp.ClientSession, device_code: str, polling_interval: int = 5
-):
+) -> str:
     while True:
         async with web_client.post(
             'https://github.com/login/oauth/access_token',
