@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from collections.abc import Sequence
-from typing import ClassVar
+from typing import Any
 
 from typing_extensions import Literal
 
@@ -10,8 +10,8 @@ from .common import Strategy
 
 
 class ManagerResult:
-    status: ClassVar[str]
-    template: ClassVar[str]
+    status: str
+    template: str
 
     @property
     def message(self) -> str:
@@ -19,7 +19,7 @@ class ManagerResult:
 
 
 class PkgInstalled(ManagerResult):
-    status: ClassVar[Literal['success']] = 'success'
+    status: Literal['success'] = 'success'
     template = 'installed {self.pkg.version}'
 
     def __init__(self, pkg: models.Pkg) -> None:
@@ -28,7 +28,7 @@ class PkgInstalled(ManagerResult):
 
 
 class PkgUpdated(ManagerResult):
-    status: ClassVar[Literal['success']] = 'success'
+    status: Literal['success'] = 'success'
     template = 'updated {self.old_pkg.version} to {self.new_pkg.version}'
 
     def __init__(self, old_pkg: models.Pkg, new_pkg: models.Pkg) -> None:
@@ -38,7 +38,7 @@ class PkgUpdated(ManagerResult):
 
 
 class PkgRemoved(ManagerResult):
-    status: ClassVar[Literal['success']] = 'success'
+    status: Literal['success'] = 'success'
     template = 'removed'
 
     def __init__(self, old_pkg: models.Pkg) -> None:
@@ -47,7 +47,7 @@ class PkgRemoved(ManagerResult):
 
 
 class ManagerError(ManagerResult, Exception):
-    status: ClassVar[Literal['failure']] = 'failure'
+    status: Literal['failure'] = 'failure'
 
 
 class PkgAlreadyInstalled(ManagerError):
@@ -55,7 +55,7 @@ class PkgAlreadyInstalled(ManagerError):
 
 
 class PkgConflictsWithInstalled(ManagerError):
-    def __init__(self, conflicting_pkgs: Sequence[models.PkgLike]) -> None:
+    def __init__(self, conflicting_pkgs: Sequence[Any]) -> None:
         super().__init__()
         self.conflicting_pkgs = conflicting_pkgs
 
@@ -122,7 +122,7 @@ class PkgStrategyUnsupported(ManagerError):
 
 
 class InternalError(ManagerResult, Exception):
-    status: ClassVar[Literal['error']] = 'error'
+    status: Literal['error'] = 'error'
 
     def __init__(self, error: BaseException) -> None:
         super().__init__()
