@@ -1,20 +1,23 @@
 from __future__ import annotations
 
+import asyncio
+from collections.abc import Callable as C
 from functools import partial
 import json
 import shutil
 from textwrap import dedent
+from unittest import mock
 
-from click.testing import CliRunner
+from click.testing import CliRunner, Result
 from prompt_toolkit.application import create_app_session
 from prompt_toolkit.input import create_pipe_input
 from prompt_toolkit.output import DummyOutput
 import pytest
 
 from instawow import __version__
-from instawow.cli import main
-from instawow.config import Config, Flavour
-from instawow.manager import Manager
+from instawow.cli import cli
+from instawow.common import Flavour
+from instawow.config import Config
 from instawow.models import PkgList
 
 
@@ -27,24 +30,30 @@ def feed_pt():
 
 
 @pytest.fixture
-def run(monkeypatch: pytest.MonkeyPatch, event_loop, iw_config: Config, iw_web_client):
-    def runner(awaitable):
-        Manager.contextualise(web_client=iw_web_client)
-        return event_loop.run_until_complete(awaitable)
-
-    monkeypatch.setattr('instawow.cli.run_with_progress', runner)
-    monkeypatch.setenv('INSTAWOW_CONFIG_DIR', str(iw_config.config_dir))
-    yield partial(CliRunner().invoke, main, catch_exceptions=False)
+def run(
+    monkeypatch: pytest.MonkeyPatch,
+    event_loop: asyncio.AbstractEventLoop,
+    iw_config: Config,
+):
+    monkeypatch.setattr('prompt_toolkit.shortcuts.progress_bar.ProgressBar', mock.MagicMock())
+    monkeypatch.setattr('asyncio.run', event_loop.run_until_complete)
+    monkeypatch.setenv('INSTAWOW_CONFIG_DIR', str(iw_config.global_config.config_dir))
+    yield partial(CliRunner().invoke, cli, catch_exceptions=False)
 
 
 @pytest.fixture
-def install_molinari_and_run(run):
+def install_molinari_and_run(
+    run: C[[str], Result],
+):
     run('install curse:molinari')
     yield run
 
 
 @pytest.fixture
-def faux_install_molinari_and_run(iw_config: Config, run):
+def pretend_install_molinari_and_run(
+    iw_config: Config,
+    run: C[[str], Result],
+):
     molinari = iw_config.addon_dir / 'Molinari'
     molinari.mkdir()
     (molinari / 'Molinari.toc').write_text(
@@ -57,7 +66,9 @@ def faux_install_molinari_and_run(iw_config: Config, run):
 
 
 @pytest.fixture
-def molinari_version_suffix(iw_config: Config):
+def molinari_version_suffix(
+    iw_config: Config,
+):
     if iw_config.game_flavour is Flavour.vanilla_classic:
         return '-classic'
     if iw_config.game_flavour is Flavour.burning_crusade_classic:
@@ -66,8 +77,13 @@ def molinari_version_suffix(iw_config: Config):
         return ''
 
 
-@pytest.mark.parametrize('alias', ['curse:molinari', 'wowi:13188-molinari', 'tukui:1'])
-def test_valid_pkg_lifecycle(run, alias: str):
+@pytest.mark.parametrize(
+    'alias', ['curse:molinari', 'wowi:13188-molinari', 'tukui:1', 'github:p3lim-wow/Molinari']
+)
+def test_valid_pkg_lifecycle(
+    run: C[[str], Result],
+    alias: str,
+):
     assert run(f'install {alias}').output.startswith(f'✓ {alias}\n  installed')
     assert run(f'install {alias}').output == f'✗ {alias}\n  package already installed\n'
     assert run(f'update {alias}').output == f'✗ {alias}\n  package is up to date\n'
@@ -77,20 +93,28 @@ def test_valid_pkg_lifecycle(run, alias: str):
 
 
 @pytest.mark.parametrize('alias', ['curse:gargantuan-wigs'])
-def test_invalid_alias_pkg_lifecycle(run, alias: str):
+def test_nonexistent_pkg_lifecycle(
+    run: C[[str], Result],
+    alias: str,
+):
     assert run(f'install {alias}').output == f'✗ {alias}\n  package does not exist\n'
     assert run(f'update {alias}').output == f'✗ {alias}\n  package is not installed\n'
     assert run(f'remove {alias}').output == f'✗ {alias}\n  package is not installed\n'
 
 
 @pytest.mark.parametrize('alias', ['foo:bar'])
-def test_invalid_source_pkg_lifecycle(run, alias: str):
+def test_invalid_source_lifecycle(
+    run: C[[str], Result],
+    alias: str,
+):
     assert run(f'install {alias}').output == f'✗ {alias}\n  package source is invalid\n'
     assert run(f'update {alias}').output == f'✗ {alias}\n  package is not installed\n'
     assert run(f'remove {alias}').output == f'✗ {alias}\n  package is not installed\n'
 
 
-def test_reconciled_folder_conflict_on_install(run):
+def test_reconciled_folder_conflict_on_install(
+    run: C[[str], Result],
+):
     assert run('install curse:molinari').output.startswith('✓ curse:molinari\n  installed')
     assert run('install wowi:13188-molinari').output == (
         '✗ wowi:13188-molinari\n'
@@ -99,7 +123,10 @@ def test_reconciled_folder_conflict_on_install(run):
     )
 
 
-def test_unreconciled_folder_conflict_on_install(iw_config: Config, run):
+def test_unreconciled_folder_conflict_on_install(
+    iw_config: Config,
+    run: C[[str], Result],
+):
     iw_config.addon_dir.joinpath('Molinari').mkdir()
     assert (
         run('install curse:molinari').output
@@ -110,7 +137,10 @@ def test_unreconciled_folder_conflict_on_install(iw_config: Config, run):
     )
 
 
-def test_keep_folders_on_remove(iw_config: Config, install_molinari_and_run):
+def test_keep_folders_on_remove(
+    iw_config: Config,
+    install_molinari_and_run: C[[str], Result],
+):
     assert (
         install_molinari_and_run('remove --keep-folders curse:molinari').output
         == '✓ curse:molinari\n  removed\n'
@@ -118,89 +148,11 @@ def test_keep_folders_on_remove(iw_config: Config, install_molinari_and_run):
     assert iw_config.addon_dir.joinpath('Molinari').is_dir()
 
 
-def test_install_with_curse_alias(run):
-    assert run('install curse:molinari').output.startswith('✓ curse:molinari\n  installed')
-    assert run('install curse:20338').output == '✗ curse:20338\n  package already installed\n'
-    assert (
-        run('install https://www.curseforge.com/wow/addons/molinari').output
-        == '✗ curse:molinari\n  package already installed\n'
-    )
-    assert (
-        run('install https://www.curseforge.com/wow/addons/molinari/download').output
-        == '✗ curse:molinari\n  package already installed\n'
-    )
-
-
-def test_install_with_tukui_alias(iw_config: Config, run):
-    if iw_config.game_flavour is Flavour.retail:
-        assert run('install tukui:-1').output.startswith('✓ tukui:-1\n  installed')
-        assert run('install tukui:tukui').output == '✗ tukui:tukui\n  package already installed\n'
-        assert (
-            run('install https://www.tukui.org/download.php?ui=tukui').output
-            == '✗ tukui:tukui\n  package already installed\n'
-        )
-    else:
-        assert run('install tukui:-1').output == '✗ tukui:-1\n  package does not exist\n'
-        assert run('install tukui:tukui').output == '✗ tukui:tukui\n  package does not exist\n'
-        assert (
-            run('install https://www.tukui.org/download.php?ui=tukui').output
-            == '✗ tukui:tukui\n  package does not exist\n'
-        )
-    assert run('install https://www.tukui.org/addons.php?id=1').output.startswith(
-        '✓ tukui:1\n  installed'
-    )
-    assert run('install tukui:1').output == '✗ tukui:1\n  package already installed\n'
-
-
-def test_install_with_wowi_alias(run):
-    assert run('install wowi:13188').output.startswith('✓ wowi:13188\n  installed')
-    assert (
-        run('install wowi:13188-molinari').output
-        == '✗ wowi:13188-molinari\n  package already installed\n'
-    )
-    assert (
-        run('install https://www.wowinterface.com/downloads/landing.php?fileid=13188').output
-        == '✗ wowi:13188\n  package already installed\n'
-    )
-    assert (
-        run('install https://www.wowinterface.com/downloads/fileinfo.php?id=13188').output
-        == '✗ wowi:13188\n  package already installed\n'
-    )
-    assert (
-        run('install https://www.wowinterface.com/downloads/download13188-Molinari').output
-        == '✗ wowi:13188\n  package already installed\n'
-    )
-    assert (
-        run('install https://www.wowinterface.com/downloads/info13188-Molinari.html').output
-        == '✗ wowi:13188\n  package already installed\n'
-    )
-
-
-def test_install_with_github_alias(run):
-    assert run('install github:AdiAddons/AdiButtonAuras').output.startswith(
-        '✓ github:AdiAddons/AdiButtonAuras\n  installed'
-    )
-    assert (
-        run('install github:adiaddons/adibuttonauras').output
-        == '✗ github:adiaddons/adibuttonauras\n  package already installed\n'
-    )
-    assert (
-        run('install https://github.com/AdiAddons/AdiButtonAuras').output
-        == '✗ github:AdiAddons/AdiButtonAuras\n  package already installed\n'
-    )
-    assert (
-        run('install https://github.com/AdiAddons/AdiButtonAuras/releases').output
-        == '✗ github:AdiAddons/AdiButtonAuras\n  package already installed\n'
-    )
-    assert (
-        run('remove github:adiaddons/adibuttonauras').output
-        == '✓ github:adiaddons/adibuttonauras\n  removed\n'
-    )
-
-
-def test_version_strategy_lifecycle(iw_config: Config, run):
+def test_version_strategy_lifecycle(
+    run: C[[str], Result],
+):
     assert run('install curse:molinari').output.startswith(
-        '✓ curse:molinari\n  installed 90100.79-Release'
+        '✓ curse:molinari\n  installed 90105.81-Release'
     )
     assert (
         run('install --version foo curse:molinari').output
@@ -221,7 +173,10 @@ def test_version_strategy_lifecycle(iw_config: Config, run):
     assert run('remove curse:molinari').output == '✓ curse:molinari\n  removed\n'
 
 
-def test_install_options(run, molinari_version_suffix):
+def test_install_options(
+    run: C[[str], Result],
+    molinari_version_suffix: str,
+):
     assert run(
         'install'
         ' curse:molinari'
@@ -230,7 +185,7 @@ def test_install_options(run, molinari_version_suffix):
     ).output == dedent(
         f'''\
         ✓ curse:molinari
-          installed 90100.79-Release{molinari_version_suffix}
+          installed 90105.81-Release{molinari_version_suffix}
         ✗ curse:molinari
           package folders conflict with installed package Molinari
             (curse:20338)
@@ -241,7 +196,9 @@ def test_install_options(run, molinari_version_suffix):
     )
 
 
-def test_install_option_order_is_respected(run):
+def test_install_option_order_is_respected(
+    run: C[[str], Result],
+):
     assert run(
         'install'
         ' --version 80000.57-Release curse:molinari'
@@ -261,13 +218,16 @@ def test_install_option_order_is_respected(run):
     )
 
 
-def test_install_argument_is_not_required(run, molinari_version_suffix):
+def test_install_argument_is_not_required(
+    run: C[[str], Result],
+    molinari_version_suffix: str,
+):
     assert run(
         'install -s latest curse:molinari --version 80000.57-Release curse:molinari'
     ).output == dedent(
         f'''\
         ✓ curse:molinari
-          installed 90100.79-Release{molinari_version_suffix}
+          installed 90105.81-Release{molinari_version_suffix}
         ✗ curse:molinari
           package folders conflict with installed package Molinari
             (curse:20338)
@@ -275,29 +235,47 @@ def test_install_argument_is_not_required(run, molinari_version_suffix):
     )
 
 
-def test_configure__display_active_profile(iw_config: Config, run):
-    assert run('configure --active').output == iw_config.json(indent=2) + '\n'
+def test_configure__show_active_profile(
+    iw_config: Config,
+    run: C[[str], Result],
+):
+    assert run('configure --show-active').output == iw_config.json(indent=2) + '\n'
 
 
-def test_configure__create_new_profile(feed_pt, iw_config, run):
-    feed_pt(f'{iw_config.addon_dir}\r\r')
-    assert (
-        run('-p foo configure').output
-        == f'Configuration written to: {iw_config.config_dir / "profiles/foo/config.json"}\n'
+def test_configure__create_new_profile(
+    feed_pt: C[[str], None],
+    iw_config: Config,
+    run: C[[str], Result],
+):
+    feed_pt(f'{iw_config.addon_dir}\r\rY\r')
+    assert run('-p foo configure').output == (
+        'Navigate to https://github.com/login/device and paste the code below:\n'
+        '  WDJB-MJHT\n'
+        'Waiting...\n'
+        'Configuration written to:\n'
+        f'  {iw_config.global_config.config_dir / "config.json"}\n'
+        f'  {iw_config.global_config.config_dir / "profiles/foo/config.json"}\n'
     )
 
 
-def test_configure__create_new_profile_promptless(monkeypatch: pytest.MonkeyPatch, iw_config, run):
-    monkeypatch.setenv('INSTAWOW_ADDON_DIR', str(iw_config.addon_dir))
-    monkeypatch.setenv('INSTAWOW_GAME_FLAVOUR', iw_config.game_flavour.value)
-    assert (
-        run('-p foo configure --promptless').output
-        == f'Configuration written to: {iw_config.config_dir / "profiles/foo/config.json"}\n'
+def test_configure__update_existing_profile_with_opts(
+    feed_pt: C[[str], None],
+    iw_config: Config,
+    run: C[[str], Result],
+):
+    feed_pt(f'Y\r')
+    assert run('configure auto_update_check').output == (
+        'Configuration written to:\n'
+        f'  {iw_config.global_config.config_dir / "config.json"}\n'
+        f'  {iw_config.global_config.config_dir / "profiles/__default__/config.json"}\n'
     )
 
 
 @pytest.mark.parametrize('options', ['', '--undo'])
-def test_rollback__pkg_not_installed(run, options):
+def test_rollback__pkg_not_installed(
+    run: C[[str], Result],
+    options: str,
+):
     assert (
         run(f'rollback {options} curse:molinari').output
         == '✗ curse:molinari\n  package is not installed\n'
@@ -305,7 +283,10 @@ def test_rollback__pkg_not_installed(run, options):
 
 
 @pytest.mark.parametrize('options', ['', '--undo'])
-def test_rollback__unsupported(run, options):
+def test_rollback__unsupported(
+    run: C[[str], Result],
+    options: str,
+):
     assert run('install wowi:13188-molinari').exit_code == 0
     assert (
         run(f'rollback {options} wowi:13188-molinari').output
@@ -313,15 +294,20 @@ def test_rollback__unsupported(run, options):
     )
 
 
-def test_rollback__single_version(run):
+def test_rollback__single_version(
+    run: C[[str], Result],
+):
     assert run('install curse:molinari').exit_code == 0
     assert (
-        run(f'rollback curse:molinari').output
-        == '✗ curse:molinari\n  cannot find older versions\n'
+        run('rollback curse:molinari').output == '✗ curse:molinari\n  cannot find older versions\n'
     )
 
 
-def test_rollback__multiple_versions(feed_pt, run, molinari_version_suffix):
+def test_rollback__multiple_versions(
+    feed_pt: C[[str], None],
+    run: C[[str], Result],
+    molinari_version_suffix: str,
+):
     assert run('install --version 80000.57-Release curse:molinari').exit_code == 0
     assert run('remove curse:molinari').exit_code == 0
     assert run('install curse:molinari').exit_code == 0
@@ -329,25 +315,33 @@ def test_rollback__multiple_versions(feed_pt, run, molinari_version_suffix):
     assert run('rollback curse:molinari').output == dedent(
         f'''\
         ✓ curse:molinari
-          updated 90100.79-Release{molinari_version_suffix} to 80000.57-Release
+          updated 90105.81-Release{molinari_version_suffix} to 80000.57-Release
         '''
     )
 
 
-def test_rollback__multiple_versions_promptless(run, molinari_version_suffix):
+def test_rollback__multiple_versions_promptless(
+    run: C[[str], Result],
+    molinari_version_suffix: str,
+):
     assert run('install --version 80000.57-Release curse:molinari').exit_code == 0
     assert run('remove curse:molinari').exit_code == 0
     assert run('install curse:molinari').exit_code == 0
     assert run('rollback --version 80000.57-Release curse:molinari').output == dedent(
         f'''\
         ✓ curse:molinari
-          updated 90100.79-Release{molinari_version_suffix} to 80000.57-Release
+          updated 90105.81-Release{molinari_version_suffix} to 80000.57-Release
         '''
     )
 
 
 @pytest.mark.parametrize('options', ['', '--undo'])
-def test_rollback__rollback_multiple_versions(feed_pt, run, molinari_version_suffix, options):
+def test_rollback__rollback_multiple_versions(
+    feed_pt: C[[str], None],
+    run: C[[str], Result],
+    molinari_version_suffix: str,
+    options: str,
+):
     assert run('install curse:molinari').exit_code == 0
     assert run('remove curse:molinari').exit_code == 0
     assert run('install --version 80000.57-Release curse:molinari').exit_code == 0
@@ -355,19 +349,23 @@ def test_rollback__rollback_multiple_versions(feed_pt, run, molinari_version_suf
     assert run(f'rollback {options} curse:molinari').output == dedent(
         f'''\
         ✓ curse:molinari
-          updated 80000.57-Release to 90100.79-Release{molinari_version_suffix}
+          updated 80000.57-Release to 90105.81-Release{molinari_version_suffix}
         '''
     )
 
 
-def test_rollback__cannot_use_version_with_undo(run):
-    result = run(f'rollback --version foo --undo curse:molinari')
+def test_rollback__cannot_use_version_with_undo(
+    run: C[[str], Result],
+):
+    result = run('rollback --version foo --undo curse:molinari')
     assert result.exit_code == 2
-    assert 'Cannot use "--version" and "--undo" together' in result.output
+    assert 'Cannot use "--version" with "--undo"' in result.output
 
 
-def test_reconcile__list_unreconciled(faux_install_molinari_and_run):
-    assert faux_install_molinari_and_run('reconcile --list-unreconciled').output == (
+def test_reconcile__list_unreconciled(
+    pretend_install_molinari_and_run: C[[str], Result],
+):
+    assert pretend_install_molinari_and_run('reconcile --list-unreconciled').output == (
         # fmt: off
         'unreconciled\n'
         '------------\n'
@@ -376,68 +374,117 @@ def test_reconcile__list_unreconciled(faux_install_molinari_and_run):
     )
 
 
-def test_reconcile__auto_reconcile(faux_install_molinari_and_run, molinari_version_suffix):
-    assert faux_install_molinari_and_run('reconcile --auto').output == dedent(
+def test_reconcile__auto_reconcile(
+    pretend_install_molinari_and_run: C[[str], Result],
+    molinari_version_suffix: str,
+):
+    assert pretend_install_molinari_and_run('reconcile --auto').output == dedent(
         f'''\
         ✓ curse:molinari
-          installed 90100.79-Release{molinari_version_suffix}
+          installed 90105.81-Release{molinari_version_suffix}
         '''
     )
 
 
-def test_reconcile__abort_interactive_reconciliation(feed_pt, faux_install_molinari_and_run):
+def test_reconcile__abort_interactive_reconciliation(
+    feed_pt: C[[str], None],
+    pretend_install_molinari_and_run: C[[str], Result],
+):
     feed_pt('\x03')  # ^C
-    assert faux_install_molinari_and_run('reconcile').output.endswith('Aborted!\n')
+    assert pretend_install_molinari_and_run('reconcile').output.endswith('Aborted!\n')
 
 
 def test_reconcile__complete_interactive_reconciliation(
-    feed_pt, faux_install_molinari_and_run, molinari_version_suffix
+    feed_pt: C[[str], None],
+    pretend_install_molinari_and_run: C[[str], Result],
+    molinari_version_suffix,
 ):
     feed_pt('\r\r')
-    assert faux_install_molinari_and_run('reconcile').output.endswith(
+    assert pretend_install_molinari_and_run('reconcile').output.endswith(
         dedent(
             f'''\
             ✓ curse:molinari
-              installed 90100.79-Release{molinari_version_suffix}
+              installed 90105.81-Release{molinari_version_suffix}
             '''
         )
     )
 
 
-def test_reconcile__reconciliation_complete(run):
+def test_reconcile__reconciliation_complete(
+    run: C[[str], Result],
+):
     assert run('reconcile').output == 'No add-ons left to reconcile.\n'
 
 
-def test_search__no_results(feed_pt, run):
-    assert run('search ∅').output == 'No results found.\n'
-
-
-def test_search__exit_without_selecting(feed_pt, run):
-    feed_pt('\r')  # enter
-    assert run('search molinari').output == ''
-
-
-def test_search__exit_after_selection(feed_pt, run):
-    feed_pt(' \rn')  # space, enter, "n"
-    assert run('search molinari').output == ''
-
-
-def test_search__install_one(feed_pt, run, molinari_version_suffix):
-    feed_pt(' \r\r')  # space, enter, enter
-    assert run('search molinari --source curse').output == dedent(
+def test_reconcile__rereconcile(
+    feed_pt: C[[str], None],
+    install_molinari_and_run: C[[str], Result],
+):
+    feed_pt('\r\r')
+    assert install_molinari_and_run('reconcile --installed').output == dedent(
         f'''\
         ✓ curse:molinari
-          installed 90100.79-Release{molinari_version_suffix}
+          removed
+        ✓ github:p3lim-wow/molinari
+          installed 90105.81-Release
         '''
     )
 
 
-def test_search__install_multiple_conflicting(feed_pt, run):
+def test_reconcile__cannot_use_auto_with_installed(
+    run: C[[str], Result],
+):
+    result = run('reconcile --auto --installed')
+    assert result.exit_code == 2
+    assert 'Cannot use "--auto" with "--installed"' in result.output
+
+
+@pytest.mark.skip
+def test_search__no_results(
+    run: C[[str], Result],
+):
+    assert run('search ∅').output == 'No results found.\n'
+
+
+def test_search__exit_without_selecting(
+    feed_pt: C[[str], None],
+    run: C[[str], Result],
+):
+    feed_pt('\r')  # enter
+    assert run('search molinari').output == ''
+
+
+def test_search__exit_after_selection(
+    feed_pt: C[[str], None],
+    run: C[[str], Result],
+):
+    feed_pt(' \rn')  # space, enter, "n"
+    assert run('search molinari').output == ''
+
+
+def test_search__install_one(
+    feed_pt: C[[str], None],
+    run: C[[str], Result],
+    molinari_version_suffix: str,
+):
+    feed_pt(' \r\r')  # space, enter, enter
+    assert run('search molinari --source curse').output == dedent(
+        f'''\
+        ✓ curse:molinari
+          installed 90105.81-Release{molinari_version_suffix}
+        '''
+    )
+
+
+def test_search__install_multiple_conflicting(
+    feed_pt: C[[str], None],
+    run: C[[str], Result],
+):
     feed_pt(' \x1b[B \r\r')  # space, arrow down, space, enter, enter
     assert run('search molinari').output == dedent(
         f'''\
         ✓ wowi:13188-molinari
-          installed 90100.79-Release
+          installed 90105.81-Release
         ✗ curse:molinari
           package folders conflict with installed package Molinari
             (wowi:13188)
@@ -445,33 +492,41 @@ def test_search__install_multiple_conflicting(feed_pt, run):
     )
 
 
-def test_changelog_output(install_molinari_and_run):
+def test_changelog_output(
+    install_molinari_and_run: C[[str], Result],
+):
     output = (
-        'Changes in 90100.79-Release:'
+        'Changes in 90105.81-Release:'
         if shutil.which('pandoc')
-        else '<h3>Changes in 90100.79-Release:</h3>'
+        else '<h3>Changes in 90105.81-Release:</h3>'
     )
     assert install_molinari_and_run('view-changelog curse:molinari').output.startswith(output)
 
 
-def test_changelog_output_no_convert(install_molinari_and_run):
+def test_changelog_output_no_convert(
+    install_molinari_and_run: C[[str], Result],
+):
     assert install_molinari_and_run(
         'view-changelog --no-convert curse:molinari'
-    ).output.startswith('<h3>Changes in 90100.79-Release:</h3>')
+    ).output.startswith('<h3>Changes in 90105.81-Release:</h3>')
 
 
-def test_argless_changelog_output(install_molinari_and_run):
+def test_argless_changelog_output(
+    install_molinari_and_run: C[[str], Result],
+):
     output = (
-        'curse:molinari:\n  Changes in 90100.79-Release:'
+        'curse:molinari:\n  Changes in 90105.81-Release:'
         if shutil.which('pandoc')
-        else 'curse:molinari:\n  <h3>Changes in 90100.79-Release:</h3>'
+        else 'curse:molinari:\n  <h3>Changes in 90105.81-Release:</h3>'
     )
     assert install_molinari_and_run('view-changelog').output.startswith(output)
 
 
-def test_argless_changelog_output_no_convert(install_molinari_and_run):
+def test_argless_changelog_output_no_convert(
+    install_molinari_and_run: C[[str], Result],
+):
     assert install_molinari_and_run('view-changelog --no-convert').output.startswith(
-        'curse:molinari:\n  <h3>Changes in 90100.79-Release:</h3>'
+        'curse:molinari:\n  <h3>Changes in 90105.81-Release:</h3>'
     )
 
 
@@ -485,13 +540,18 @@ def test_argless_changelog_output_no_convert(install_molinari_and_run):
     ],
 )
 def test_exit_codes_with_substr_match(
-    monkeypatch: pytest.MonkeyPatch, install_molinari_and_run, command, exit_code
+    monkeypatch: pytest.MonkeyPatch,
+    install_molinari_and_run: C[[str], Result],
+    command: str,
+    exit_code: int,
 ):
-    monkeypatch.setattr('click.launch', lambda *a, **k: ...)
+    monkeypatch.setattr('click.launch', lambda *_, **__: ...)
     assert install_molinari_and_run(command).exit_code == exit_code
 
 
-def test_can_list_with_substr_match(install_molinari_and_run):
+def test_can_list_with_substr_match(
+    install_molinari_and_run: C[[str], Result],
+):
     assert install_molinari_and_run('list mol').output == 'curse:molinari\n'
     assert install_molinari_and_run('list foo').output == ''
     assert install_molinari_and_run('list -f detailed mol').output.startswith('curse:molinari')
@@ -499,15 +559,21 @@ def test_can_list_with_substr_match(install_molinari_and_run):
     assert (molinari['source'], molinari['slug']) == ('curse', 'molinari')
 
 
-def test_json_export(install_molinari_and_run):
+def test_json_export(
+    install_molinari_and_run: C[[str], Result],
+):
     output = install_molinari_and_run('list -f json').output
     assert PkgList.parse_raw(output).__root__[0].name == 'Molinari'
 
 
-def test_show_version(run):
+def test_show_version(
+    run: C[[str], Result],
+):
     assert run('--version').output == f'instawow, version {__version__}\n'
 
 
-def test_plugin_hook_command_can_be_invoked(run):
+def test_plugin_hook_command_can_be_invoked(
+    run: C[[str], Result],
+):
     pytest.importorskip('instawow_test_plugin')
     assert run('foo').output == 'success!\n'
